#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

from django.contrib import admin
from django.contrib.contenttypes.admin import GenericTabularInline

from django.utils.translation import ugettext_lazy as _
from filebrowser.settings import ADMIN_THUMBNAIL


class SectionAdminMixin(object):

    sortable_field_name = 'order'
    show_change_link = True

    list_display = ('__str__', 'image_thumbnail')
    list_filter = ()
    search_fields = ('title', 'description', 'slug')
    date_hierarchy = 'created'
    save_as = True
    save_on_top = True
    actions_on_top = True
    actions_on_bottom = True

    def image_thumbnail(self, obj):
        if obj.image and obj.image.filetype == "Image":
            url = obj.image.version_generate(ADMIN_THUMBNAIL).url
            return '<img src="{}" />'.format(url)
        else:
            return ""
    image_thumbnail.allow_tags = True
    image_thumbnail.short_description = "Thumbnail"

    extra = 0
    sortable_field_name = 'order'
    show_change_link = True

    related_lookup_fields = {
        'generic': [['content_type', 'object_id']],

    }


class SectionInlineAdminBase(SectionAdminMixin, GenericTabularInline):
    ct_field = "section_content_type"
    ct_fk_field = "section_object_id"

    readonly_fields = ('edit_link', )

    fieldsets = ((
        None, {
            'fields': (
                ('template_name', ),
                ('title', ),
                ('status', ),
                ('order', ),
                ('edit_link', ),
            )
        }), )

    def edit_link(self, obj):
        if obj:
            return """<a href="/admin/sections/section/{}/">edit</a>
        """.format(obj.pk)
    edit_link.allow_tags = True
    edit_link.short_description = 'edit'


class SectionAdminBase(SectionAdminMixin, admin.ModelAdmin):

    add_fieldsets = ((
        None, {
            'classes': ('wide',),
            'fields': (
                ('section_content_type', 'section_object_id'),
                ('template_name', ),
                ('title', ),
            )
        }),
    )
    fieldsets = ((
        None, {
            'classes': ('wide',),
            'fields': (
                ('section_content_type', 'section_object_id'),
                ('template_name', ),
                ('title', ),
                ('description', ),
                ('image', ),
                ('content_type', 'object_id'),
                ('options', ),
                ('order', ),
            )
        }), (
        _("Activation"), {
            'classes': ('grp-collapse', 'grp-closed'),
            'fields': (
                ('status', ),
                ('activate_date', 'deactivate_date'),
            )
        }))

    def get_fieldsets(self, request, obj=None):
        if not obj:
            return self.add_fieldsets
        return super(SectionAdminBase, self).get_fieldsets(request, obj)

    def get_form(self, request, obj=None, **kwargs):
        """
        Use special form during object creation
        """
        defaults = {}
        if obj is None:
            defaults['form'] = self.add_form
        defaults.update(kwargs)
        return super(SectionAdminBase, self).get_form(request, obj, **defaults)

    def response_add(self, request, obj, post_url_continue=None):
        if '_addanother' not in request.POST:
            request.POST['_continue'] = 1
        return super(SectionAdminBase, self).response_add(request, obj,
                                                          post_url_continue)



from django import forms
from django.conf import settings

from optionsfield.fields import OptionsWidget


class SectionAdminFormBase(forms.ModelForm):

    template_name = forms.TypedChoiceField(
        required=False, label=u"Template",
        help_text=("Defines template type in which this object will be "
                   "rendered. Various templates have different look and "
                   "use different fields and options. Please refer to "
                   "documentation for details on template types."))

    def __init__(self, *args, **kwargs):
        super(SectionAdminFormBase, self).__init__(*args, **kwargs)
        choices = ((None, '------'), ) + self._meta.model.TEMPLATE_NAME_CHOICES
        self.fields['template_name'].choices = choices

        if 'title' in self.fields:
            self.fields['title'].help_text = "Name of a object - used in " \
                "templates as a <strong>headline</strong> or just for identification"

        if 'description' in self.fields:
            self.fields['description'].help_text = "<strong>copy,</strong> content of object"

        if 'options' in self.fields:
            self.fields['options'].widget = OptionsWidget()

        if 'tinymce' in settings.INSTALLED_APPS and 'description' in self.fields:
            from tinymce.widgets import TinyMCE
            self.fields['description'].widget = \
                TinyMCE(attrs={'cols': 80, 'rows': 30})


class SectionInlineAdminFormBase(SectionAdminFormBase):
    def __init__(self, *args, **kwargs):
        super(SectionInlineAdminFormBase, self).__init__(*args, **kwargs)
        # remove help text from inline formset as its too long and breaks look
        self.fields['template_name'].help_text = None
        self.fields['title'].help_text = None



#!/usr/bin/env python
# -*- coding: utf-8 -*-

__author__ = u"Rafał Selewońko <rafal@selewonko.com>"

from django.contrib import admin

from gipsy.sections.admin_base import SectionAdminBase, SectionInlineAdminBase
from gipsy.sections.forms import SectionAdminForm, SectionInlineAdminForm
from gipsy.sections.models import Section


class SectionInlineAdmin(SectionInlineAdminBase):
    model = Section
    add_form = SectionInlineAdminForm
    form = SectionInlineAdminForm


class SectionAdmin(SectionAdminBase):
    add_form = SectionAdminForm
    form = SectionAdminForm
    inlines = [SectionInlineAdmin]

    def _create_formsets(self, request, obj, change):
        "Override to not display inlines in add_view."
        if not change:
            self.inlines = []
        return super(SectionAdmin, self)._create_formsets(request, obj, change)


admin.site.register(Section, SectionAdmin)



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models
import optionsfield.fields
import django_extensions.db.fields


class Migration(migrations.Migration):

    dependencies = [
        ('sections', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='section',
            name='created',
            field=django_extensions.db.fields.CreationDateTimeField(auto_now_add=True, verbose_name='created'),
        ),
        migrations.AlterField(
            model_name='section',
            name='modified',
            field=django_extensions.db.fields.ModificationDateTimeField(auto_now=True, verbose_name='modified'),
        ),
        migrations.AlterField(
            model_name='section',
            name='options',
            field=optionsfield.fields.OptionsField(verbose_name='options', types=(basestring,)),
        ),
        migrations.AlterField(
            model_name='section',
            name='section_object_id',
            field=models.PositiveIntegerField(help_text="Specifies object to which this section is attached to. Do not change if you're unsure what does that it do.", null=True, blank=True),
        ),
    ]
